=== modified file 'bzrlib/tests/test_http.py'
--- bzrlib/tests/test_http.py	2007-07-04 12:28:56 +0000
+++ bzrlib/tests/test_http.py	2007-10-17 17:22:26 +0000
@@ -29,6 +29,7 @@
 
 import bzrlib
 from bzrlib import (
+    config,
     errors,
     osutils,
     ui,
@@ -1297,6 +1298,25 @@
         # Only one 'Authentication Required' error should occur
         self.assertEqual(1, self.server.auth_required_errors)
 
+    def test_no_prompt_for_password_when_using_auth_config(self):
+        user =' joe'
+        password = 'foo'
+        stdin_content = 'bar\n'  # Not the right password
+        self.server.add_user(user, password)
+        t = self.get_user_transport(user, None)
+        ui.ui_factory = TestUIFactory(stdin=stdin_content)
+        # Create a minimal config file with the right password
+        conf = config.AuthenticationConfig()
+        conf._get_config().update(
+            {'httptest': {'scheme': 'http', 'port': self.server.port,
+                          'user': user, 'password': password}})
+        conf._save()
+        # Issue a request to the server to connect
+        self.assertEqual('contents of a\n',t.get('a').read())
+        # stdin should have  been left untouched
+        self.assertEqual(stdin_content, ui.ui_factory.stdin.readline())
+
+
 
 class TestHTTPAuth(TestAuth):
     """Test HTTP authentication schemes.

=== modified file 'bzrlib/transport/ftp.py'
--- bzrlib/transport/ftp.py	2007-10-17 15:36:20 +0000
+++ bzrlib/transport/ftp.py	2007-10-17 17:22:26 +0000
@@ -133,8 +133,9 @@
             if self._user and self._user != 'anonymous' and \
                     password is None: # '' is a valid password
                 auth = config.AuthenticationConfig()
-                config_credentials = auth.get_credentials('ftp', self._host,
-                                                          user=self._user)
+                config_credentials = auth.get_credentials(
+                    'ftp', self._host, self._port, user=self._user,
+                    path=self._path)
                 if config_credentials is not None:
                     password = config_credentials['password']
                 else:

=== modified file 'bzrlib/transport/http/_urllib2_wrappers.py'
--- bzrlib/transport/http/_urllib2_wrappers.py	2007-07-04 12:28:56 +0000
+++ bzrlib/transport/http/_urllib2_wrappers.py	2007-10-17 17:22:26 +0000
@@ -60,6 +60,7 @@
 
 from bzrlib import __version__ as bzrlib_version
 from bzrlib import (
+    config,
     errors,
     ui,
     )
@@ -1006,15 +1007,29 @@
             password = None
 
         if password is None:
-            # Prompt user only if we can't find a password
-            if realm:
-                realm_prompt = " Realm: '%s'" % realm
-            else:
-                realm_prompt = ''
-            scheme, host, path, query, fragment = urlparse.urlsplit(authuri)
-            password = ui.ui_factory.get_password(prompt=self.password_prompt,
-                                                  user=user, host=host,
-                                                  realm=realm_prompt)
+            scheme, netloc, path, query, fragment = urlparse.urlsplit(authuri)
+            if ':' in netloc:
+                host, port = netloc.rsplit(':', 1)
+                # port is an int here invalid values have been handled by the
+                # upper layers
+                port = int(port)
+            else:
+                host = netloc
+                port = None
+            auth = config.AuthenticationConfig()
+            config_credentials = auth.get_credentials(
+                scheme, host, port, user=user, path=path)
+            if config_credentials is not None:
+                password = config_credentials['password']
+            else:
+                # Prompt user only if we can't find a password
+                if realm:
+                    realm_prompt = " Realm: '%s'" % realm
+                else:
+                    realm_prompt = ''
+                password = ui.ui_factory.get_password(
+                    prompt=self.password_prompt, user=user, host=netloc,
+                    realm=realm_prompt)
             if password is not None:
                 self.add_password(realm, authuri, user, password)
         return password

